Crate rustadex

Crate rustadex 

Rustadex

This is a placeholder crate for the upcoming Rustadex Codex.

The goal of this project is to provide a unified, ergonomic facade for a suite of powerful Rust libraries.

This crate is currently under active development and is not yet functional.

Functions

hello
A placeholder function that will be part of the future API.